NoteHandler class

Properties

database Future<Database>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance NoteHandler
final

Static Methods

deleteAllNotes() → dynamic
deleteNote(int id) → dynamic
getAllNotes() → dynamic
insert(String title, String desc) → dynamic
update(Note note) → dynamic

Constants

columnDate → const String
columnDesc → const String
columnId → const String
columnTitle → const String
table → const String